
# Type: label type


A string that provides a human-readable name for a thing

URI: [biolink:LabelType](https://w3id.org/biolink/vocab/LabelType)

|  |  |  |
| --- | --- | --- |
| Parent type | | [String](types/String.md) |
| Root (builtin) type | | **str** |
